@@ -12,14 +12,14 @@ library(magrittr)
 
 ## ----warning=FALSE, message=FALSE----------------------------------------
 select_columns <- c("Species", "Petal.Length", "Petal.Width")
-myft <- flextable(iris[46:55,], col_keys = select_columns) %>% 
+myft <- regulartable(iris[46:55,], col_keys = select_columns) %>% 
   merge_v(~ Species + Petal.Width )
 
 tabwid(myft) 
 
 ## ----warning=FALSE, message=FALSE----------------------------------------
 select_columns <- c("Species", "Petal.Length", "Petal.Width")
-myft <- flextable(head(mtcars, n = 10 ) ) %>% 
+myft <- regulartable(head(mtcars, n = 10 ) ) %>% 
   merge_h( ) %>%
   border(border = fp_border(), part = "all") # and add borders
 
@@ -27,7 +27,7 @@ tabwid(myft)
 
 ## ----warning=FALSE, message=FALSE----------------------------------------
 select_columns <- c("Species", "Petal.Length", "Petal.Width")
-myft <- flextable(head(mtcars, n = 6 ) ) %>% 
+myft <- regulartable(head(mtcars, n = 6 ) ) %>% 
   merge_at( i = 1:3, j = 1:3) %>%
   border(border = fp_border(), part = "all") # and add borders
 
@@ -37,25 +37,22 @@ tabwid(myft)
 tabwid(myft %>% merge_none())
 
 ## ------------------------------------------------------------------------
-library(dplyr)
-iris %>% 
-  group_by(Species) %>% 
-  do( head(., n = 3) ) %>% 
-  flextable(col_keys = c("Species", "Sepal.Length", "Petal.Length") ) %>%
+data <- iris[c(1:3, 51:53, 101:104),]
+
+regulartable(data, col_keys = c("Species", "Sepal.Length", "Petal.Length") ) %>%
   theme_booktabs() %>% 
   tabwid()
 
 
 ## ------------------------------------------------------------------------
-iris %>% group_by(Species) %>% do( head(., n = 3) ) %>%
-  flextable(col_keys = c("Species", "col_1", "Sepal.Length", "Petal.Length") ) %>%
+regulartable(data = data, col_keys = c("Species", "col_1", "Sepal.Length", "Petal.Length") ) %>%
   theme_vanilla() %>% autofit() %>% 
   border(j=2, border = fp_border(width=0), part = "all") %>% 
   tabwid()
 
 
 ## ----warning=FALSE, message=FALSE----------------------------------------
-ft <- flextable( head( iris ) ) %>% 
+ft <- regulartable( head( iris ) ) %>% 
   set_header_labels(Sepal.Length = "Sepal", 
     Sepal.Width = "Sepal", Petal.Length = "Petal",
     Petal.Width = "Petal", Species = "Species" )
@@ -89,13 +86,13 @@ typology <- data.frame(
 typology %>% flextable() %>% theme_vanilla() %>% autofit() %>% tabwid()
 
 ## ----warning=FALSE, message=FALSE----------------------------------------
-flextable( head( iris ) ) %>% 
+regulartable( head( iris ) ) %>% 
   set_header_df( mapping = typology, key = "col_keys" ) %>% 
   merge_h(part = "header") %>% merge_v(part = "header") %>% 
   theme_vanilla() %>% autofit() %>% tabwid()
 
 ## ------------------------------------------------------------------------
-ft_base <- flextable(head(iris)) %>% 
+ft_base <- regulartable(head(iris)) %>% 
   theme_tron_legacy()
 tabwid(ft_base)
 dim(ft_base)
@@ -113,6 +110,6 @@ tabwid(ft)
 ## ------------------------------------------------------------------------
 ft <- ft_base %>% autofit() %>% 
   width(j = ~ Species, width = 2) %>% 
-  height(i = 4:5, height = .5)
+  height( height = .4, part = "all" )
 tabwid(ft)
 
